==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/pl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Powiadomienia o aktualizacji",
    "Could not start updater, please try the manual update" : "Nie można uruchomić aktualizacji, spróbuj z aktualizować ręcznie",
    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Dowiedz się jak zaktualizować.",
    "Channel updated" : "Zaktualizowany kanał",
    "The update server could not be reached since %d days to check for new updates." : "Połączenie z serwerem z aktualizacjami w celu sprawdzenia nowych aktualizacji nie powiodło się od %d dni.",
    "Update to %1$s is available." : "Aktualizacja do %1$s jest dostępna.",
    "Update for %1$s to version %2$s is available." : "Jest dostępna aktualizacja dla %1$s do wersji %2$s",
    "Update for {app} to version %s is available." : "aktualizacja dla {app} do wersji %s jest dostępna.",
    "A new version is available: %s" : "Dostępna jest nowa wersja: %s",
    "Open updater" : "Otwórz aktualizator",
    "Download now" : "Pobierz teraz",
    "Your version is up to date." : "Posiadasz aktualną wersję.",
    "Checked on %s" : "Sprawdzone na %s",
    "Update channel:" : "Kanał aktualizacji:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Zawsze możesz zaktualizować do nowszej wersji z eksperymentalnego kanału. Ale nigdy nie możesz powrócić do wersji ze stabilnego kanału.",
    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach: ",
    "Only notification for app updates are available." : "Tylko powiadomienia o aktualizacjach aplikacji są dostępne.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Wybrany kanał aktualizacji dla dedykowanych powiadomień dla serwera jest nieaktualny.",
    "The selected update channel does not support updates of the server." : "Wybrany kanał aktualizacji nie obsługuje danego serwera."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/pl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Powiadomienia o aktualizacji",
    "Could not start updater, please try the manual update" : "Nie można uruchomić aktualizacji, spróbuj z aktualizować ręcznie",
    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Dowiedz się jak zaktualizować.",
    "Channel updated" : "Zaktualizowany kanał",
    "The update server could not be reached since %d days to check for new updates." : "Połączenie z serwerem z aktualizacjami w celu sprawdzenia nowych aktualizacji nie powiodło się od %d dni.",
    "Please check the Nextcloud and server log files for errors." : "Proszę sprawdzić pliki z logami Nextcloud i serwera w celu poszukiwania błędów.",
    "Update to %1$s is available." : "Aktualizacja do %1$s jest dostępna.",
    "Update for %1$s to version %2$s is available." : "Jest dostępna aktualizacja dla %1$s do wersji %2$s",
    "Update for {app} to version %s is available." : "aktualizacja dla {app} do wersji %s jest dostępna.",
    "Update notification" : "Powiadomienie o aktualizacji",
    "A new version is available: %s" : "Dostępna jest nowa wersja: %s",
    "Open updater" : "Otwórz aktualizator",
    "Download now" : "Pobierz teraz",
    "Your version is up to date." : "Posiadasz aktualną wersję.",
    "Checked on %s" : "Sprawdzone na %s",
    "Update channel:" : "Kanał aktualizacji:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Zawsze możesz zaktualizować do nowszej wersji z eksperymentalnego kanału. Ale nigdy nie możesz powrócić do wersji ze stabilnego kanału.",
    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach: ",
    "Only notification for app updates are available." : "Tylko powiadomienia o aktualizacjach aplikacji są dostępne.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Wybrany kanał aktualizacji dla dedykowanych powiadomień dla serwera jest nieaktualny.",
    "The selected update channel does not support updates of the server." : "Wybrany kanał aktualizacji nie obsługuje danego serwera."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
